# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/protobuf/util/json_format.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&google/protobuf/util/json_format.proto\x12\x11protobuf_unittest\"\x89\x01\n\x13TestFlagsAndStrings\x12\t\n\x01\x41\x18\x01 \x02(\x05\x12K\n\rrepeatedgroup\x18\x02 \x03(\n24.protobuf_unittest.TestFlagsAndStrings.RepeatedGroup\x1a\x1a\n\rRepeatedGroup\x12\t\n\x01\x66\x18\x03 \x02(\t\"!\n\x14TestBase64ByteArrays\x12\t\n\x01\x61\x18\x01 \x02(\x0c\"G\n\x12TestJavaScriptJSON\x12\t\n\x01\x61\x18\x01 \x01(\x05\x12\r\n\x05\x66inal\x18\x02 \x01(\x02\x12\n\n\x02in\x18\x03 \x01(\t\x12\x0b\n\x03Var\x18\x04 \x01(\t\"Q\n\x18TestJavaScriptOrderJSON1\x12\t\n\x01\x64\x18\x01 \x01(\x05\x12\t\n\x01\x63\x18\x02 \x01(\x05\x12\t\n\x01x\x18\x03 \x01(\x08\x12\t\n\x01\x62\x18\x04 \x01(\x05\x12\t\n\x01\x61\x18\x05 \x01(\x05\"\x89\x01\n\x18TestJavaScriptOrderJSON2\x12\t\n\x01\x64\x18\x01 \x01(\x05\x12\t\n\x01\x63\x18\x02 \x01(\x05\x12\t\n\x01x\x18\x03 \x01(\x08\x12\t\n\x01\x62\x18\x04 \x01(\x05\x12\t\n\x01\x61\x18\x05 \x01(\x05\x12\x36\n\x01z\x18\x06 \x03(\x0b\x32+.protobuf_unittest.TestJavaScriptOrderJSON1\"$\n\x0cTestLargeInt\x12\t\n\x01\x61\x18\x01 \x02(\x03\x12\t\n\x01\x62\x18\x02 \x02(\x04\"\xa0\x01\n\x0bTestNumbers\x12\x30\n\x01\x61\x18\x01 \x01(\x0e\x32%.protobuf_unittest.TestNumbers.MyType\x12\t\n\x01\x62\x18\x02 \x01(\x05\x12\t\n\x01\x63\x18\x03 \x01(\x02\x12\t\n\x01\x64\x18\x04 \x01(\x08\x12\t\n\x01\x65\x18\x05 \x01(\x01\x12\t\n\x01\x66\x18\x06 \x01(\r\"(\n\x06MyType\x12\x06\n\x02OK\x10\x00\x12\x0b\n\x07WARNING\x10\x01\x12\t\n\x05\x45RROR\x10\x02\"T\n\rTestCamelCase\x12\x14\n\x0cnormal_field\x18\x01 \x01(\t\x12\x15\n\rCAPITAL_FIELD\x18\x02 \x01(\x05\x12\x16\n\x0e\x43\x61melCaseField\x18\x03 \x01(\x05\"|\n\x0bTestBoolMap\x12=\n\x08\x62ool_map\x18\x01 \x03(\x0b\x32+.protobuf_unittest.TestBoolMap.BoolMapEntry\x1a.\n\x0c\x42oolMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"O\n\rTestRecursion\x12\r\n\x05value\x18\x01 \x01(\x05\x12/\n\x05\x63hild\x18\x02 \x01(\x0b\x32 .protobuf_unittest.TestRecursion\"\x86\x01\n\rTestStringMap\x12\x43\n\nstring_map\x18\x01 \x03(\x0b\x32/.protobuf_unittest.TestStringMap.StringMapEntry\x1a\x30\n\x0eStringMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc4\x01\n\x14TestStringSerializer\x12\x15\n\rscalar_string\x18\x01 \x01(\t\x12\x17\n\x0frepeated_string\x18\x02 \x03(\t\x12J\n\nstring_map\x18\x03 \x03(\x0b\x32\x36.protobuf_unittest.TestStringSerializer.StringMapEntry\x1a\x30\n\x0eStringMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"$\n\x18TestMessageWithExtension*\x08\x08\x64\x10\x80\x80\x80\x80\x02\"z\n\rTestExtension\x12\r\n\x05value\x18\x01 \x01(\t2Z\n\x03\x65xt\x12+.protobuf_unittest.TestMessageWithExtension\x18\x64 \x01(\x0b\x32 .protobuf_unittest.TestExtension\"Q\n\x14TestDefaultEnumValue\x12\x39\n\nenum_value\x18\x01 \x01(\x0e\x32\x1c.protobuf_unittest.EnumValue:\x07\x44\x45\x46\x41ULT*2\n\tEnumValue\x12\x0c\n\x08PROTOCOL\x10\x00\x12\n\n\x06\x42UFFER\x10\x01\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x02')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.protobuf.util.json_format_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TESTBOOLMAP_BOOLMAPENTRY']._options = None
  _globals['_TESTBOOLMAP_BOOLMAPENTRY']._serialized_options = b'8\001'
  _globals['_TESTSTRINGMAP_STRINGMAPENTRY']._options = None
  _globals['_TESTSTRINGMAP_STRINGMAPENTRY']._serialized_options = b'8\001'
  _globals['_TESTSTRINGSERIALIZER_STRINGMAPENTRY']._options = None
  _globals['_TESTSTRINGSERIALIZER_STRINGMAPENTRY']._serialized_options = b'8\001'
  _globals['_ENUMVALUE']._serialized_start=1607
  _globals['_ENUMVALUE']._serialized_end=1657
  _globals['_TESTFLAGSANDSTRINGS']._serialized_start=62
  _globals['_TESTFLAGSANDSTRINGS']._serialized_end=199
  _globals['_TESTFLAGSANDSTRINGS_REPEATEDGROUP']._serialized_start=173
  _globals['_TESTFLAGSANDSTRINGS_REPEATEDGROUP']._serialized_end=199
  _globals['_TESTBASE64BYTEARRAYS']._serialized_start=201
  _globals['_TESTBASE64BYTEARRAYS']._serialized_end=234
  _globals['_TESTJAVASCRIPTJSON']._serialized_start=236
  _globals['_TESTJAVASCRIPTJSON']._serialized_end=307
  _globals['_TESTJAVASCRIPTORDERJSON1']._serialized_start=309
  _globals['_TESTJAVASCRIPTORDERJSON1']._serialized_end=390
  _globals['_TESTJAVASCRIPTORDERJSON2']._serialized_start=393
  _globals['_TESTJAVASCRIPTORDERJSON2']._serialized_end=530
  _globals['_TESTLARGEINT']._serialized_start=532
  _globals['_TESTLARGEINT']._serialized_end=568
  _globals['_TESTNUMBERS']._serialized_start=571
  _globals['_TESTNUMBERS']._serialized_end=731
  _globals['_TESTNUMBERS_MYTYPE']._serialized_start=691
  _globals['_TESTNUMBERS_MYTYPE']._serialized_end=731
  _globals['_TESTCAMELCASE']._serialized_start=733
  _globals['_TESTCAMELCASE']._serialized_end=817
  _globals['_TESTBOOLMAP']._serialized_start=819
  _globals['_TESTBOOLMAP']._serialized_end=943
  _globals['_TESTBOOLMAP_BOOLMAPENTRY']._serialized_start=897
  _globals['_TESTBOOLMAP_BOOLMAPENTRY']._serialized_end=943
  _globals['_TESTRECURSION']._serialized_start=945
  _globals['_TESTRECURSION']._serialized_end=1024
  _globals['_TESTSTRINGMAP']._serialized_start=1027
  _globals['_TESTSTRINGMAP']._serialized_end=1161
  _globals['_TESTSTRINGMAP_STRINGMAPENTRY']._serialized_start=1113
  _globals['_TESTSTRINGMAP_STRINGMAPENTRY']._serialized_end=1161
  _globals['_TESTSTRINGSERIALIZER']._serialized_start=1164
  _globals['_TESTSTRINGSERIALIZER']._serialized_end=1360
  _globals['_TESTSTRINGSERIALIZER_STRINGMAPENTRY']._serialized_start=1113
  _globals['_TESTSTRINGSERIALIZER_STRINGMAPENTRY']._serialized_end=1161
  _globals['_TESTMESSAGEWITHEXTENSION']._serialized_start=1362
  _globals['_TESTMESSAGEWITHEXTENSION']._serialized_end=1398
  _globals['_TESTEXTENSION']._serialized_start=1400
  _globals['_TESTEXTENSION']._serialized_end=1522
  _globals['_TESTDEFAULTENUMVALUE']._serialized_start=1524
  _globals['_TESTDEFAULTENUMVALUE']._serialized_end=1605
# @@protoc_insertion_point(module_scope)
